@@ -28,7 +28,7 @@ from jose import jwt
 from .authorization import Authorization
 from .connection import ConnectionManager
 from .exceptions import raise_error_from_response, KeycloakGetError, \
-    KeycloakRPTNotFound, KeycloakAuthorizationConfigError, KeycloakInvalidTokenError
+    KeycloakRPTNotFound, KeycloakAuthorizationConfigError, KeycloakInvalidTokenError, KeycloakDeprecationError
 from .urls_patterns import (
     URL_REALM,
     URL_AUTH,
@@ -44,7 +44,7 @@ from .urls_patterns import (
 
 class KeycloakOpenID:
 
-    def __init__(self, server_url, realm_name, client_id, client_secret_key=None, verify=True, custom_headers=None):
+    def __init__(self, server_url, realm_name, client_id, client_secret_key=None, verify=True, custom_headers=None, proxies=None):
         """
 
         :param server_url: Keycloak server url
@@ -53,6 +53,7 @@ class KeycloakOpenID:
         :param client_secret_key: client secret key
         :param verify: True if want check connection SSL
         :param custom_headers: dict of custom header to pass to each HTML request
+        :param proxies: dict of proxies to sent the request by.
         """
         self._client_id = client_id
         self._client_secret_key = client_secret_key
@@ -64,7 +65,8 @@ class KeycloakOpenID:
         self._connection = ConnectionManager(base_url=server_url,
                                              headers=headers,
                                              timeout=60,
-                                             verify=verify)
+                                             verify=verify,
+                                             proxies=proxies)
 
         self._authorization = Authorization()
 
@@ -189,7 +191,7 @@ class KeycloakOpenID:
         payload = {"username": username, "password": password,
                    "client_id": self.client_id, "grant_type": grant_type,
                    "code": code, "redirect_uri": redirect_uri}
-        if payload:
+        if extra:
             payload.update(extra)
 
         if totp:
@@ -291,6 +293,9 @@ class KeycloakOpenID:
         self.connection.add_param_headers("Authorization", "Bearer " + token)
         params_path = {"realm-name": self.realm_name, "resource-server-id": resource_server_id}
         data_raw = self.connection.raw_get(URL_ENTITLEMENT.format(**params_path))
+        
+        if data_raw.status_code == 404: 
+            return raise_error_from_response(data_raw, KeycloakDeprecationError)
 
         return raise_error_from_response(data_raw, KeycloakGetError)
 
